==> pdfbox-android-2.0.12.0-sources.jar: com/tom_roush/pdfbox/contentstream/operator/state/SetLineJoinStyle.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tom_roush.pdfbox.contentstream.operator.state;

import android.graphics.Paint;

import java.io.IOException;
import java.util.List;

import com.tom_roush.pdfbox.contentstream.operator.MissingOperandException;
import com.tom_roush.pdfbox.contentstream.operator.Operator;
import com.tom_roush.pdfbox.contentstream.operator.OperatorProcessor;
import com.tom_roush.pdfbox.cos.COSBase;
import com.tom_roush.pdfbox.cos.COSNumber;

/**
 * j: Set the line join style.
 *
 */
public class SetLineJoinStyle extends OperatorProcessor
{
    @Override
    public void process(Operator operator, List<COSBase> arguments) throws IOException
    {
        if (arguments.size() < 1)
        {
            throw new MissingOperandException(operator, arguments);
        }

        Paint.Join lineJoinStyle;
        switch(((COSNumber)arguments.get( 0 )).intValue())  {
            case 0:
                lineJoinStyle = Paint.Join.MITER;
                break;
            case 1:
                lineJoinStyle = Paint.Join.ROUND;
                break;
            case 2:
                lineJoinStyle = Paint.Join.BEVEL;
                break;
            default:
                lineJoinStyle = null;
        }

        context.getGraphicsState().setLineJoin( lineJoinStyle );
    }

    @Override
    public String getName()
    {
        return "j";
    }
}

==> pdfbox-android-2.0.27.0-sources.jar: com/tom_roush/pdfbox/contentstream/operator/state/SetLineJoinStyle.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tom_roush.pdfbox.contentstream.operator.state;

import android.graphics.Paint;

import java.io.IOException;
import java.util.List;

import com.tom_roush.pdfbox.contentstream.operator.MissingOperandException;
import com.tom_roush.pdfbox.contentstream.operator.Operator;
import com.tom_roush.pdfbox.contentstream.operator.OperatorName;
import com.tom_roush.pdfbox.contentstream.operator.OperatorProcessor;
import com.tom_roush.pdfbox.cos.COSBase;
import com.tom_roush.pdfbox.cos.COSNumber;

/**
 * j: Set the line join style.
 *
 */
public class SetLineJoinStyle extends OperatorProcessor
{
    @Override
    public void process(Operator operator, List<COSBase> arguments) throws IOException
    {
        if (arguments.isEmpty())
        {
            throw new MissingOperandException(operator, arguments);
        }
        Paint.Join lineJoinStyle;
        switch (((COSNumber)arguments.get( 0 )).intValue())
        {
            case 0:
                lineJoinStyle = Paint.Join.MITER;
                break;
            case 1:
                lineJoinStyle = Paint.Join.ROUND;
                break;
            case 2:
                lineJoinStyle = Paint.Join.BEVEL;
                break;
            default:
                lineJoinStyle = null;
        }
        context.getGraphicsState().setLineJoin( lineJoinStyle );
    }

    @Override
    public String getName()
    {
        return OperatorName.SET_LINE_JOINSTYLE;
    }
}
